==> GNUMail-1.0.3.tar.gz: GNUMail/MailWindowController.h <==
/*
**  MailWindowController.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#import <AppKit/AppKit.h>

@class FilterManager;
@class Folder;
@class LabelWidget;
@class LocalStore;
@class MailHeaderCell;
@class MailWindow;
@class Message;
@class POP3Folder;
@class URLName;

@interface MailWindowController : NSWindowController
{
  //
  // Outlets
  //
  IBOutlet NSScrollView *tableScrollView; 
  IBOutlet NSScrollView *textScrollView;

  IBOutlet NSSplitView *splitView;
  IBOutlet NSTableView *tableView;
  IBOutlet NSTextView *textView;

#ifdef MACOSX
  IBOutlet NSView *navigationView;
#endif

  IBOutlet NSButton *delete;
  IBOutlet NSButton *mailboxes;
  IBOutlet NSButton *compose;
  IBOutlet NSButton *forward;
  IBOutlet NSButton *reply;
  IBOutlet NSButton *addresses;
  IBOutlet NSButton *find;

  IBOutlet NSTextField *label;
  IBOutlet NSMatrix *matrix;
  
  IBOutlet NSTableColumn *statusColumn;
  IBOutlet NSTableColumn *idColumn;
  IBOutlet NSTableColumn *dateColumn;
  IBOutlet NSTableColumn *fromColumn;
  IBOutlet NSTableColumn *subjectColumn;
  IBOutlet NSTableColumn *sizeColumn;

  IBOutlet NSImageView *icon;
  IBOutlet NSImageView *secureConnectionIcon;

  IBOutlet id get;

  //
  // Other ivars
  //
  NSMutableArray *allMessageViewWindowControllers;
  NSMutableArray *filteredMessageBoxes;
  NSMutableArray *allConnections;
  NSArray *allMessages;

  FilterManager *filterManager;
  Folder *folder;

  MailHeaderCell *mailHeaderCell;

  NSString *previousOrder;
  NSString *currentOrder;
  
  NSTimer *animation;
  NSTimer *timer;
  
  NSLock *lock;

  int transferredMessageCount, filteredMessageCount;
  int animation_index;
  int threadCount;

  BOOL initiatedFromTimer;
  BOOL mustStopTransfer;
  BOOL shouldCloseStore;
  BOOL isReverseOrder;
  BOOL showAllHeaders;
  BOOL showRawSource;
  BOOL showStatusBar;
  BOOL isReloading;

  @public
    IBOutlet NSButton *next;
    IBOutlet NSButton *previous;
}

- (id) initWithWindowNibName: (NSString *) windowNibName;
- (void) dealloc;

//
// action methods
//
- (IBAction) doubleClickedOnTableView: (id) sender;

- (IBAction) deleteMessage: (id) sender;

- (IBAction) lastMessage: (id) sender;
- (IBAction) firstMessage: (id) sender;

- (IBAction) nextMessage: (id) sender;
- (IBAction) previousMessage: (id) sender;

- (IBAction) composeMessage: (id) sender;
- (IBAction) forwardMessage: (id) sender;
- (IBAction) replyMessage: (id) sender;
- (IBAction) replyAllMessage: (id) sender;
- (IBAction) viewMessageInWindow: (id) sender;

- (IBAction) loadFilters: (id) sender;
- (IBAction) updateMessageFlags: (id) sender;

- (IBAction) updateAnimatedIcon: (id) sender;

- (IBAction) getNewMessages: (id) sender;

- (void) startTimer: (id) sender;
- (void) stopTimer: (id) sender;


//
// access / mutation methods
//
- (Folder *) folder;
- (void) setFolder: (Folder *) theFolder;

- (NSArray *) allMessages;

- (Message *) selectedMessage;
- (NSArray *) selectedMessages;

- (BOOL) showAllHeaders;
- (void) setShowAllHeaders: (BOOL) aBOOL;

- (BOOL) showRawSource;
- (void) setShowRawSource: (BOOL) aBool;

- (BOOL) showStatusBar;
- (void) setShowStatusBar: (BOOL) aBOOL;

- (NSTableView *) tableView;
- (NSTextView *) textView;

- (NSString *) currentOrder;
- (void) setCurrentOrder: (NSString *) theCurrentOrder;

- (NSString *) previousOrder;
- (void) setPreviousOrder: (NSString *) thePreviousOrder;

- (NSImageView *) secureConnectionIcon;

- (id) mustStopTransfer;

- (MailHeaderCell *) mailHeaderCell;

- (NSMutableArray *) allMessageViewWindowControllers;

//
// delegate methods
//
- (int) numberOfRowsInTableView: (NSTableView *)aTableView;

- (id)           tableView: (NSTableView *) aTableView
 objectValueForTableColumn: (NSTableColumn *) aTableColumn
                       row: (int) rowIndex;

- (void) tableView: (NSTableView *) aTableView
   willDisplayCell: (id) aCell
    forTableColumn: (NSTableColumn *) aTableColumn
               row: (int) rowIndex;

- (void) tableViewSelectionDidChange: (NSNotification *) aNotification;

-  (void) textView: (NSTextView *) aTextView
     clickedOnCell: (id <NSTextAttachmentCell>) attachmentCell
	    inRect: (NSRect) cellFrame
           atIndex: (unsigned) charIndex;

- (BOOL) textView: (NSTextView *) textView
    clickedOnLink: (id) link 
          atIndex: (unsigned) charIndex;

- (BOOL) windowShouldClose: (id) sender;

- (void) windowWillClose: (NSNotification *) not;

- (void) windowDidLoad;

- (void) windowDidBecomeKey: (NSNotification *) aNotification;


//
// Other methods
//
- (oneway void) communicationErrorOccuredOnServer: (NSString *) theServer;

- (oneway void) invalidPasswordOnServer: (NSString *) theServer
                               username: (NSString *) theUsername;

- (void) messageWasReceived: (NSData *) theMessage
                 forURLName: (URLName *) theURLName;

- (oneway void) messagesWereReceived;

- (oneway void) noNewMessagesOnServer: (NSString *) theServer
                             username: (NSString *) theUsername;

- (void) reloadTableColumns;

- (void) setSelectedMessagesAsTransferred;

- (void) tableViewShouldReloadData;

- (oneway void) threadWillExit;

- (void) updateStatusLabel;

- (void) verifyForNewMailOnStartup;

@end


//
// Private interface for MailWindowContrller
//
@interface MailWindowController (Private)

- (void) _closeAllMessageViewWindows;

- (void) _launchExternalProgram: (NSDictionary *) theDictionary;

- (void) _loadAccessoryViews;

- (void) _matchFilterRuleFromRawSource: (NSData *) theRawSource
                            connection: (NSConnection *) theConnection
                                   key: (NSString *) theKey;

- (void) _restoreSortingOrder;

- (void) _restoreSplitViewSize;

- (void) _transferMessagesUsingInfoFromDictionary: (NSDictionary *) theDictionary;

- (int) _transferMessagesFromPOP3Folder: (POP3Folder *) theFolder
                             connection: (NSConnection *) theConnection
                                    key: (NSString *) theKey;

- (void) _updateMessageSelectionUsingIndex: (int) theIndex;

@end

==> GNUMail-1.2.0pre1.tar.gz: GNUMail/MailWindowController.h <==
/*
**  MailWindowController.h
**
**  Copyright (c) 2001-2004
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_MailWindowController
#define _GNUMail_H_MailWindowController

#import <Foundation/Foundation.h>
#import <AppKit/AppKit.h>

@class ExtendedOutlineView;
@class CWFolder;
@class CWLocalStore;
@class CWMessage;
@class CWPOP3Folder;
@class CWURLName;
@class FolderNode;
@class LabelWidget;
@class MailHeaderCell;
@class ThreadArcsCell;
@class MailWindow;


@interface MailWindowController : NSWindowController
{
  //
  // Outlets
  //
  IBOutlet NSScrollView *tableScrollView; 
  IBOutlet NSScrollView *textScrollView;

  IBOutlet NSSplitView *splitView;
  IBOutlet NSTextView *textView;

  IBOutlet NSButton *mailboxes;
  IBOutlet NSButton *compose;
  IBOutlet NSButton *forward;
  IBOutlet NSButton *reply;
  IBOutlet NSButton *addresses;
  IBOutlet NSButton *find;

  IBOutlet NSTextField *label;
  
  IBOutlet NSTableColumn *flaggedColumn;
  IBOutlet NSTableColumn *statusColumn;
  IBOutlet NSTableColumn *idColumn;
  IBOutlet NSTableColumn *dateColumn;
  IBOutlet NSTableColumn *fromColumn;
  IBOutlet NSTableColumn *subjectColumn;
  IBOutlet NSTableColumn *sizeColumn;

  IBOutlet NSButton *icon;
  IBOutlet NSMenu *menu;
  
#ifdef MACOSX
  IBOutlet NSProgressIndicator *progressIndicator;
  IBOutlet NSDrawer *drawer;
  IBOutlet ExtendedOutlineView *outlineView;
#endif

  //
  // Other ivars
  //
  NSMutableArray *allMessageViewWindowControllers;
  NSArray *_allMessages;
  
  FolderNode *allNodes;
  CWFolder *_folder;

  MailHeaderCell *mailHeaderCell;
  ThreadArcsCell *threadArcsCell;
  NSTimer *animation;
  int animation_index;
   
  id dataView;

  BOOL draftsOrSentFolder;
  BOOL shouldCloseStore;
  BOOL showAllHeaders;
  BOOL showRawSource;
  
  NSMutableArray *allowedToolbarItemIdentifiers;
  NSMutableDictionary *additionalToolbarItems;

  //
  // Public ivars
  //
  @public
    IBOutlet NSButton *next;
    IBOutlet NSButton *previous;
    IBOutlet id get;
    IBOutlet id delete;
}


//
// Action methods
//
- (IBAction) doubleClickedOnDataView: (id) sender;

- (IBAction) deleteMessage: (id) sender;

- (IBAction) lastMessage: (id) sender;
- (IBAction) firstMessage: (id) sender;

- (IBAction) pageDownMessage: (id) sender;
- (IBAction) pageUpMessage: (id) sender;

- (IBAction) nextMessage: (id) sender;
- (IBAction) nextUnreadMessage: (id) sender;
- (IBAction) previousMessage: (id) sender;
- (IBAction) previousUnreadMessage: (id) sender;

- (IBAction) forwardMessage: (id) sender;
- (IBAction) replyToMessage: (id) sender;

- (IBAction) viewMessageInWindow: (id) sender;

- (IBAction) getNewMessages: (id) sender;

- (IBAction) copyOrMoveMessages: (id) sender;

#ifdef MACOSX
- (IBAction) openOrCloseDrawer: (id) sender;
#endif

//
// Access / mutation methods
//
- (CWFolder *) folder;
- (void) setFolder: (CWFolder *) theFolder;

- (CWMessage *) selectedMessage;
- (NSArray *) selectedMessages;

- (BOOL) showAllHeaders;
- (void) setShowAllHeaders: (BOOL) aBOOL;

- (BOOL) showRawSource;
- (void) setShowRawSource: (BOOL) aBool;

- (id) dataView;
- (void) setDataViewType: (int) theType;

- (NSTextView *) textView;

- (MailHeaderCell *) mailHeaderCell;
- (ThreadArcsCell *) threadArcsCell;

- (NSMutableArray *) allMessageViewWindowControllers;

- (NSArray *) allMessages;


//
// delegate methods
//
- (NSMenu *) dataView: (id) aDataView
    contextMenuForRow: (int) theRow;

- (int) numberOfRowsInTableView: (NSTableView *)aTableView;

- (id)           tableView: (NSTableView *) aTableView
 objectValueForTableColumn: (NSTableColumn *) aTableColumn
                       row: (int) rowIndex;

- (void) tableView: (NSTableView *) aTableView
   willDisplayCell: (id) aCell
    forTableColumn: (NSTableColumn *) aTableColumn
               row: (int) rowIndex;

- (void) tableViewSelectionDidChange: (NSNotification *) aNotification;

- (void) tableView: (NSTableView *) theTableView
  didReceiveTyping: (NSString *) theString;

-  (void) textView: (NSTextView *) aTextView
     clickedOnCell: (id <NSTextAttachmentCell>) attachmentCell
	    inRect: (NSRect) cellFrame
           atIndex: (unsigned) charIndex;

- (BOOL) textView: (NSTextView *) textView
    clickedOnLink: (id) link 
          atIndex: (unsigned) charIndex;

- (BOOL) windowShouldClose: (id) sender;
- (void) windowWillClose: (NSNotification *) not;
- (void) windowDidLoad;
- (void) windowDidBecomeKey: (NSNotification *) aNotification;


//
// Other methods
//
- (void) startAnimation;
- (void) stopAnimation;

- (void) tableViewShouldReloadData;

- (void) updateDataView;
- (void) updateStatusLabel;
- (void) updateWindowTitle;

@end


//
// Private interface for MailWindowContrller
//
@interface MailWindowController (Private)

- (void) _addSenderToAddressBook;
- (void) _closeAllMessageViewWindows;
- (void) _filtersHaveChanged: (NSNotification *) theNotification;
- (void) _fontValuesHaveChanged;
- (void) _loadAccessoryViews;
- (void) _reloadMessageList: (NSNotification *) theNotification;
- (void) _reloadTableColumns: (id) sender;
- (void) _restoreImage;
- (void) _restoreSortingOrder;
- (void) _restoreSplitViewSize;
- (void) _setIndicatorImageForTableColumn: (NSTableColumn *) aTableColumn;
- (void) _showMessage: (id) sender;
- (void) _updateAnimatedIcon: (id) sender;
- (void) _zeroIndexOffset;

@end

#endif // _GNUMail_H_MailWindowController
